import unittest

from dropbox_sign import ApiClient, Configuration, apis, models as m
from test_utils import get_fixture_data, MockPoolManager, get_base_path


class TestTemplateApi(unittest.TestCase):
    def setUp(self):
        self.configuration = Configuration()
        self.api_client = ApiClient(self.configuration)
        self.mock_pool = MockPoolManager(self)
        self.api_client.rest_client.pool_manager = self.mock_pool

        self.api = apis.TemplateApi(self.api_client)

    def test_template_add_user(self):
        template_id = "f57db65d3f933b5316d398057a36176831451a35"

        request_class = "TemplateAddUserRequest"
        request_data = get_fixture_data(request_class)["default"]

        response_class = "TemplateGetResponse"
        response_data = get_fixture_data(response_class)["default"]

        self.mock_pool.expect_request(
            content_type="application/json", data=request_data, response=response_data
        )
        expected = m.TemplateGetResponse.init(response_data)
        obj = m.TemplateAddUserRequest.init(request_data)

        result = self.api.template_add_user(template_id, obj)

        self.assertEqual(result.__class__.__name__, response_class)
        self.assertEqual(result, expected)

    def test_template_create_embedded_draft(self):
        request_class = "TemplateCreateEmbeddedDraftRequest"
        request_data = get_fixture_data(request_class)["default"]

        response_class = "TemplateCreateEmbeddedDraftResponse"
        response_data = get_fixture_data(response_class)["default"]

        self.mock_pool.expect_request(
            content_type="multipart/form-data",
            data=request_data,
            response=response_data,
        )
        expected = m.TemplateCreateEmbeddedDraftResponse.init(response_data)
        obj = m.TemplateCreateEmbeddedDraftRequest.init(request_data)
        obj.files = [open(f"{get_base_path()}/pdf-sample.pdf", "rb")]

        result = self.api.template_create_embedded_draft(obj)

        self.assertEqual(result.__class__.__name__, response_class)
        self.assertEqual(result, expected)

        obj.files[0].close()

    def test_template_delete(self):
        self.skipTest("skipping test_template_delete")

    def test_template_files(self):
        self.skipTest("skipping test_template_files")

    def test_template_get(self):
        template_id = "f57db65d3f933b5316d398057a36176831451a35"

        response_class = "TemplateGetResponse"
        response_data = get_fixture_data(response_class)["default"]

        self.mock_pool.expect_request(
            content_type="application/json", response=response_data
        )
        expected = m.TemplateGetResponse.init(response_data)

        result = self.api.template_get(template_id)

        self.assertEqual(result.__class__.__name__, response_class)
        self.assertEqual(result, expected)

    def test_template_list(self):
        account_id = "all"

        response_class = "TemplateListResponse"
        response_data = get_fixture_data(response_class)["default"]

        self.mock_pool.expect_request(
            content_type="application/json", response=response_data
        )
        expected = m.TemplateListResponse.init(response_data)

        result = self.api.template_list(account_id=account_id)

        self.assertEqual(result.__class__.__name__, response_class)
        self.assertEqual(result, expected)

    def test_template_remove_user(self):
        template_id = "21f920ec2b7f4b6bb64d3ed79f26303843046536"

        request_class = "TemplateRemoveUserRequest"
        request_data = get_fixture_data(request_class)["default"]

        response_class = "TemplateGetResponse"
        response_data = get_fixture_data(response_class)["default"]

        self.mock_pool.expect_request(
            content_type="application/json", data=request_data, response=response_data
        )
        expected = m.TemplateGetResponse.init(response_data)
        obj = m.TemplateRemoveUserRequest.init(request_data)

        result = self.api.template_remove_user(template_id, obj)

        self.assertEqual(result.__class__.__name__, response_class)
        self.assertEqual(result, expected)

    def test_template_update_files(self):
        template_id = "21f920ec2b7f4b6bb64d3ed79f26303843046536"

        request_class = "TemplateUpdateFilesRequest"
        request_data = get_fixture_data(request_class)["default"]

        response_class = "TemplateUpdateFilesResponse"
        response_data = get_fixture_data(response_class)["default"]

        self.mock_pool.expect_request(
            content_type="multipart/form-data",
            data=request_data,
            response=response_data,
        )
        expected = m.TemplateUpdateFilesResponse.init(response_data)
        obj = m.TemplateUpdateFilesRequest.init(request_data)
        obj.files = [open(f"{get_base_path()}/pdf-sample.pdf", "rb")]

        result = self.api.template_update_files(template_id, obj)

        self.assertEqual(result.__class__.__name__, response_class)
        self.assertEqual(result, expected)

        obj.files[0].close()


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class FaxLineAreaCodeGetCountryEnum(str, Enum):
    """
    FaxLineAreaCodeGetCountryEnum
    """

    """
    allowed enum values
    """
    CA = "CA"
    US = "US"
    UK = "UK"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of FaxLineAreaCodeGetCountryEnum from a JSON string"""
        return cls(json.loads(json_str))



# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictBytes, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from dropbox_sign.models.sub_attachment import SubAttachment
from dropbox_sign.models.sub_field_options import SubFieldOptions
from dropbox_sign.models.sub_form_field_group import SubFormFieldGroup
from dropbox_sign.models.sub_form_field_rule import SubFormFieldRule
from dropbox_sign.models.sub_form_fields_per_document_base import (
    SubFormFieldsPerDocumentBase,
)
from dropbox_sign.models.sub_merge_field import SubMergeField
from dropbox_sign.models.sub_template_role import SubTemplateRole
from typing import Optional, Set, Tuple
from typing_extensions import Self
import io
from pydantic import StrictBool
from typing import Union


class TemplateCreateRequest(BaseModel):
    """
    TemplateCreateRequest
    """  # noqa: E501

    form_fields_per_document: List[SubFormFieldsPerDocumentBase] = Field(
        description="The fields that should appear on the document, expressed as an array of objects. (For more details you can read about it here: [Using Form Fields per Document](/docs/openapi/form-fields-per-document).)  **NOTE:** Fields like **text**, **dropdown**, **checkbox**, **radio**, and **hyperlink** have additional required and optional parameters. Check out the list of [additional parameters](/api/reference/constants/#form-fields-per-document) for these field types.  * Text Field use `SubFormFieldsPerDocumentText` * Dropdown Field use `SubFormFieldsPerDocumentDropdown` * Hyperlink Field use `SubFormFieldsPerDocumentHyperlink` * Checkbox Field use `SubFormFieldsPerDocumentCheckbox` * Radio Field use `SubFormFieldsPerDocumentRadio` * Signature Field use `SubFormFieldsPerDocumentSignature` * Date Signed Field use `SubFormFieldsPerDocumentDateSigned` * Initials Field use `SubFormFieldsPerDocumentInitials` * Text Merge Field use `SubFormFieldsPerDocumentTextMerge` * Checkbox Merge Field use `SubFormFieldsPerDocumentCheckboxMerge`"
    )
    signer_roles: List[SubTemplateRole] = Field(
        description="An array of the designated signer roles that must be specified when sending a SignatureRequest using this Template."
    )
    files: Optional[List[Union[StrictBytes, StrictStr, io.IOBase]]] = Field(
        default=None,
        description="Use `files[]` to indicate the uploaded file(s) to send for signature.  This endpoint requires either **files** or **file_urls[]**, but not both.",
    )
    file_urls: Optional[List[StrictStr]] = Field(
        default=None,
        description="Use `file_urls[]` to have Dropbox Sign download the file(s) to send for signature.  This endpoint requires either **files** or **file_urls[]**, but not both.",
    )
    allow_reassign: Optional[StrictBool] = Field(
        default=False,
        description="Allows signers to reassign their signature requests to other signers if set to `true`. Defaults to `false`.  **NOTE:** Only available for Premium plan and higher.",
    )
    attachments: Optional[List[SubAttachment]] = Field(
        default=None, description="A list describing the attachments"
    )
    cc_roles: Optional[List[StrictStr]] = Field(
        default=None,
        description="The CC roles that must be assigned when using the template to send a signature request",
    )
    client_id: Optional[StrictStr] = Field(
        default=None,
        description="Client id of the app you're using to create this draft. Used to apply the branding and callback url defined for the app.",
    )
    field_options: Optional[SubFieldOptions] = None
    form_field_groups: Optional[List[SubFormFieldGroup]] = Field(
        default=None,
        description="Group information for fields defined in `form_fields_per_document`. String-indexed JSON array with `group_label` and `requirement` keys. `form_fields_per_document` must contain fields referencing a group defined in `form_field_groups`.",
    )
    form_field_rules: Optional[List[SubFormFieldRule]] = Field(
        default=None,
        description="Conditional Logic rules for fields defined in `form_fields_per_document`.",
    )
    merge_fields: Optional[List[SubMergeField]] = Field(
        default=None,
        description="Add merge fields to the template. Merge fields are placed by the user creating the template and used to pre-fill data by passing values into signature requests with the `custom_fields` parameter. If the signature request using that template *does not* pass a value into a merge field, then an empty field remains in the document.",
    )
    message: Optional[Annotated[str, Field(strict=True, max_length=5000)]] = Field(
        default=None, description="The default template email message."
    )
    metadata: Optional[Dict[str, Any]] = Field(
        default=None,
        description="Key-value data that should be attached to the signature request. This metadata is included in all API responses and events involving the signature request. For example, use the metadata field to store a signer's order number for look up when receiving events for the signature request.  Each request can include up to 10 metadata keys (or 50 nested metadata keys), with key names up to 40 characters long and values up to 1000 characters long.",
    )
    subject: Optional[Annotated[str, Field(strict=True, max_length=200)]] = Field(
        default=None, description="The template title (alias)."
    )
    test_mode: Optional[StrictBool] = Field(
        default=False,
        description="Whether this is a test, the signature request created from this draft will not be legally binding if set to `true`. Defaults to `false`.",
    )
    title: Optional[StrictStr] = Field(
        default=None,
        description="The title you want to assign to the SignatureRequest.",
    )
    use_preexisting_fields: Optional[StrictBool] = Field(
        default=False,
        description="Enable the detection of predefined PDF fields by setting the `use_preexisting_fields` to `true` (defaults to disabled, or `false`).",
    )
    __properties: ClassVar[List[str]] = [
        "form_fields_per_document",
        "signer_roles",
        "files",
        "file_urls",
        "allow_reassign",
        "attachments",
        "cc_roles",
        "client_id",
        "field_options",
        "form_field_groups",
        "form_field_rules",
        "merge_fields",
        "message",
        "metadata",
        "subject",
        "test_mode",
        "title",
        "use_preexisting_fields",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        arbitrary_types_allowed=True,
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    def to_json_form_params(
        self, excluded_fields: Set[str] = None
    ) -> List[Tuple[str, str]]:
        data: List[Tuple[str, str]] = []

        for key, value in self.to_dict(excluded_fields).items():
            if isinstance(value, (int, str, bool)):
                data.append((key, value))
            else:
                data.append((key, json.dumps(value, ensure_ascii=False)))

        return data

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TemplateCreateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self, excluded_fields: Set[str] = None) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in form_fields_per_document (list)
        _items = []
        if self.form_fields_per_document:
            for _item_form_fields_per_document in self.form_fields_per_document:
                if _item_form_fields_per_document:
                    _items.append(_item_form_fields_per_document.to_dict())
            _dict["form_fields_per_document"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in signer_roles (list)
        _items = []
        if self.signer_roles:
            for _item_signer_roles in self.signer_roles:
                if _item_signer_roles:
                    _items.append(_item_signer_roles.to_dict())
            _dict["signer_roles"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in attachments (list)
        _items = []
        if self.attachments:
            for _item_attachments in self.attachments:
                if _item_attachments:
                    _items.append(_item_attachments.to_dict())
            _dict["attachments"] = _items
        # override the default output from pydantic by calling `to_dict()` of field_options
        if self.field_options:
            _dict["field_options"] = self.field_options.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in form_field_groups (list)
        _items = []
        if self.form_field_groups:
            for _item_form_field_groups in self.form_field_groups:
                if _item_form_field_groups:
                    _items.append(_item_form_field_groups.to_dict())
            _dict["form_field_groups"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in form_field_rules (list)
        _items = []
        if self.form_field_rules:
            for _item_form_field_rules in self.form_field_rules:
                if _item_form_field_rules:
                    _items.append(_item_form_field_rules.to_dict())
            _dict["form_field_rules"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in merge_fields (list)
        _items = []
        if self.merge_fields:
            for _item_merge_fields in self.merge_fields:
                if _item_merge_fields:
                    _items.append(_item_merge_fields.to_dict())
            _dict["merge_fields"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TemplateCreateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "form_fields_per_document": (
                    [
                        SubFormFieldsPerDocumentBase.from_dict(_item)
                        for _item in obj["form_fields_per_document"]
                    ]
                    if obj.get("form_fields_per_document") is not None
                    else None
                ),
                "signer_roles": (
                    [SubTemplateRole.from_dict(_item) for _item in obj["signer_roles"]]
                    if obj.get("signer_roles") is not None
                    else None
                ),
                "files": obj.get("files"),
                "file_urls": obj.get("file_urls"),
                "allow_reassign": (
                    obj.get("allow_reassign")
                    if obj.get("allow_reassign") is not None
                    else False
                ),
                "attachments": (
                    [SubAttachment.from_dict(_item) for _item in obj["attachments"]]
                    if obj.get("attachments") is not None
                    else None
                ),
                "cc_roles": obj.get("cc_roles"),
                "client_id": obj.get("client_id"),
                "field_options": (
                    SubFieldOptions.from_dict(obj["field_options"])
                    if obj.get("field_options") is not None
                    else None
                ),
                "form_field_groups": (
                    [
                        SubFormFieldGroup.from_dict(_item)
                        for _item in obj["form_field_groups"]
                    ]
                    if obj.get("form_field_groups") is not None
                    else None
                ),
                "form_field_rules": (
                    [
                        SubFormFieldRule.from_dict(_item)
                        for _item in obj["form_field_rules"]
                    ]
                    if obj.get("form_field_rules") is not None
                    else None
                ),
                "merge_fields": (
                    [SubMergeField.from_dict(_item) for _item in obj["merge_fields"]]
                    if obj.get("merge_fields") is not None
                    else None
                ),
                "message": obj.get("message"),
                "metadata": obj.get("metadata"),
                "subject": obj.get("subject"),
                "test_mode": (
                    obj.get("test_mode") if obj.get("test_mode") is not None else False
                ),
                "title": obj.get("title"),
                "use_preexisting_fields": (
                    obj.get("use_preexisting_fields")
                    if obj.get("use_preexisting_fields") is not None
                    else False
                ),
            }
        )
        return _obj

    @classmethod
    def init(cls, data: Any) -> Self:
        """
        Attempt to instantiate and hydrate a new instance of this class
        """
        if isinstance(data, str):
            data = json.loads(data)

        return cls.from_dict(data)

    @classmethod
    def openapi_types(cls) -> Dict[str, str]:
        return {
            "form_fields_per_document": "(List[SubFormFieldsPerDocumentBase],)",
            "signer_roles": "(List[SubTemplateRole],)",
            "files": "(List[io.IOBase],)",
            "file_urls": "(List[str],)",
            "allow_reassign": "(bool,)",
            "attachments": "(List[SubAttachment],)",
            "cc_roles": "(List[str],)",
            "client_id": "(str,)",
            "field_options": "(SubFieldOptions,)",
            "form_field_groups": "(List[SubFormFieldGroup],)",
            "form_field_rules": "(List[SubFormFieldRule],)",
            "merge_fields": "(List[SubMergeField],)",
            "message": "(str,)",
            "metadata": "(Dict[str, object],)",
            "subject": "(str,)",
            "test_mode": "(bool,)",
            "title": "(str,)",
            "use_preexisting_fields": "(bool,)",
        }

    @classmethod
    def openapi_type_is_array(cls, property_name: str) -> bool:
        return property_name in [
            "form_fields_per_document",
            "signer_roles",
            "files",
            "file_urls",
            "attachments",
            "cc_roles",
            "form_field_groups",
            "form_field_rules",
            "merge_fields",
        ]



# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set, Tuple
from typing_extensions import Self
import io
from pydantic import StrictBool
from typing import Union


class UnclaimedDraftResponse(BaseModel):
    """
    A group of documents that a user can take ownership of via the claim URL.
    """  # noqa: E501

    signature_request_id: Optional[StrictStr] = Field(
        default=None,
        description="The ID of the signature request that is represented by this UnclaimedDraft.",
    )
    claim_url: Optional[StrictStr] = Field(
        default=None, description="The URL to be used to claim this UnclaimedDraft."
    )
    signing_redirect_url: Optional[StrictStr] = Field(
        default=None,
        description="The URL you want signers redirected to after they successfully sign.",
    )
    requesting_redirect_url: Optional[StrictStr] = Field(
        default=None,
        description="The URL you want signers redirected to after they successfully request a signature (Will only be returned in the response if it is applicable to the request.).",
    )
    expires_at: Optional[StrictInt] = Field(
        default=None, description="When the link expires."
    )
    test_mode: Optional[StrictBool] = Field(
        default=None,
        description="Whether this is a test draft. Signature requests made from test drafts have no legal value.",
    )
    __properties: ClassVar[List[str]] = [
        "signature_request_id",
        "claim_url",
        "signing_redirect_url",
        "requesting_redirect_url",
        "expires_at",
        "test_mode",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        arbitrary_types_allowed=True,
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    def to_json_form_params(
        self, excluded_fields: Set[str] = None
    ) -> List[Tuple[str, str]]:
        data: List[Tuple[str, str]] = []

        for key, value in self.to_dict(excluded_fields).items():
            if isinstance(value, (int, str, bool)):
                data.append((key, value))
            else:
                data.append((key, json.dumps(value, ensure_ascii=False)))

        return data

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UnclaimedDraftResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self, excluded_fields: Set[str] = None) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UnclaimedDraftResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "signature_request_id": obj.get("signature_request_id"),
                "claim_url": obj.get("claim_url"),
                "signing_redirect_url": obj.get("signing_redirect_url"),
                "requesting_redirect_url": obj.get("requesting_redirect_url"),
                "expires_at": obj.get("expires_at"),
                "test_mode": obj.get("test_mode"),
            }
        )
        return _obj

    @classmethod
    def init(cls, data: Any) -> Self:
        """
        Attempt to instantiate and hydrate a new instance of this class
        """
        if isinstance(data, str):
            data = json.loads(data)

        return cls.from_dict(data)

    @classmethod
    def openapi_types(cls) -> Dict[str, str]:
        return {
            "signature_request_id": "(str,)",
            "claim_url": "(str,)",
            "signing_redirect_url": "(str,)",
            "requesting_redirect_url": "(str,)",
            "expires_at": "(int,)",
            "test_mode": "(bool,)",
        }

    @classmethod
    def openapi_type_is_array(cls, property_name: str) -> bool:
        return property_name in []



# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from dropbox_sign.models.bulk_send_job_get_response import BulkSendJobGetResponse
from dropbox_sign.models.bulk_send_job_list_response import BulkSendJobListResponse

from dropbox_sign.api_client import ApiClient, RequestSerialized
from dropbox_sign.api_response import ApiResponse
from dropbox_sign.rest import RESTResponseType
import io


class BulkSendJobApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def bulk_send_job_get(
        self,
        bulk_send_job_id: Annotated[
            StrictStr, Field(description="The id of the BulkSendJob to retrieve.")
        ],
        page: Annotated[
            Optional[StrictInt],
            Field(
                description="Which page number of the BulkSendJob list to return. Defaults to `1`."
            ),
        ] = None,
        page_size: Annotated[
            Optional[StrictInt],
            Field(
                description="Number of objects to be returned per page. Must be between `1` and `100`. Default is 20."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> BulkSendJobGetResponse:
        """Get Bulk Send Job

        Returns the status of the BulkSendJob and its SignatureRequests specified by the `bulk_send_job_id` parameter.

        :param bulk_send_job_id: The id of the BulkSendJob to retrieve. (required)
        :type bulk_send_job_id: str
        :param page: Which page number of the BulkSendJob list to return. Defaults to `1`.
        :type page: int
        :param page_size: Number of objects to be returned per page. Must be between `1` and `100`. Default is 20.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._bulk_send_job_get_serialize(
            bulk_send_job_id=bulk_send_job_id,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "BulkSendJobGetResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def bulk_send_job_get_with_http_info(
        self,
        bulk_send_job_id: Annotated[
            StrictStr, Field(description="The id of the BulkSendJob to retrieve.")
        ],
        page: Annotated[
            Optional[StrictInt],
            Field(
                description="Which page number of the BulkSendJob list to return. Defaults to `1`."
            ),
        ] = None,
        page_size: Annotated[
            Optional[StrictInt],
            Field(
                description="Number of objects to be returned per page. Must be between `1` and `100`. Default is 20."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[BulkSendJobGetResponse]:
        """Get Bulk Send Job

        Returns the status of the BulkSendJob and its SignatureRequests specified by the `bulk_send_job_id` parameter.

        :param bulk_send_job_id: The id of the BulkSendJob to retrieve. (required)
        :type bulk_send_job_id: str
        :param page: Which page number of the BulkSendJob list to return. Defaults to `1`.
        :type page: int
        :param page_size: Number of objects to be returned per page. Must be between `1` and `100`. Default is 20.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._bulk_send_job_get_serialize(
            bulk_send_job_id=bulk_send_job_id,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "BulkSendJobGetResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def bulk_send_job_get_without_preload_content(
        self,
        bulk_send_job_id: Annotated[
            StrictStr, Field(description="The id of the BulkSendJob to retrieve.")
        ],
        page: Annotated[
            Optional[StrictInt],
            Field(
                description="Which page number of the BulkSendJob list to return. Defaults to `1`."
            ),
        ] = None,
        page_size: Annotated[
            Optional[StrictInt],
            Field(
                description="Number of objects to be returned per page. Must be between `1` and `100`. Default is 20."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Bulk Send Job

        Returns the status of the BulkSendJob and its SignatureRequests specified by the `bulk_send_job_id` parameter.

        :param bulk_send_job_id: The id of the BulkSendJob to retrieve. (required)
        :type bulk_send_job_id: str
        :param page: Which page number of the BulkSendJob list to return. Defaults to `1`.
        :type page: int
        :param page_size: Number of objects to be returned per page. Must be between `1` and `100`. Default is 20.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._bulk_send_job_get_serialize(
            bulk_send_job_id=bulk_send_job_id,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "BulkSendJobGetResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _bulk_send_job_get_serialize(
        self,
        bulk_send_job_id,
        page,
        page_size,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if bulk_send_job_id is not None:
            _path_params["bulk_send_job_id"] = bulk_send_job_id
        # process the query parameters
        if page is not None:

            _query_params.append(("page", page))

        if page_size is not None:

            _query_params.append(("page_size", page_size))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["api_key", "oauth2"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/bulk_send_job/{bulk_send_job_id}",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def bulk_send_job_list(
        self,
        page: Annotated[
            Optional[StrictInt],
            Field(
                description="Which page number of the BulkSendJob List to return. Defaults to `1`."
            ),
        ] = None,
        page_size: Annotated[
            Optional[StrictInt],
            Field(
                description="Number of objects to be returned per page. Must be between `1` and `100`. Default is 20."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> BulkSendJobListResponse:
        """List Bulk Send Jobs

        Returns a list of BulkSendJob that you can access.

        :param page: Which page number of the BulkSendJob List to return. Defaults to `1`.
        :type page: int
        :param page_size: Number of objects to be returned per page. Must be between `1` and `100`. Default is 20.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._bulk_send_job_list_serialize(
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "BulkSendJobListResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def bulk_send_job_list_with_http_info(
        self,
        page: Annotated[
            Optional[StrictInt],
            Field(
                description="Which page number of the BulkSendJob List to return. Defaults to `1`."
            ),
        ] = None,
        page_size: Annotated[
            Optional[StrictInt],
            Field(
                description="Number of objects to be returned per page. Must be between `1` and `100`. Default is 20."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[BulkSendJobListResponse]:
        """List Bulk Send Jobs

        Returns a list of BulkSendJob that you can access.

        :param page: Which page number of the BulkSendJob List to return. Defaults to `1`.
        :type page: int
        :param page_size: Number of objects to be returned per page. Must be between `1` and `100`. Default is 20.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._bulk_send_job_list_serialize(
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "BulkSendJobListResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def bulk_send_job_list_without_preload_content(
        self,
        page: Annotated[
            Optional[StrictInt],
            Field(
                description="Which page number of the BulkSendJob List to return. Defaults to `1`."
            ),
        ] = None,
        page_size: Annotated[
            Optional[StrictInt],
            Field(
                description="Number of objects to be returned per page. Must be between `1` and `100`. Default is 20."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Bulk Send Jobs

        Returns a list of BulkSendJob that you can access.

        :param page: Which page number of the BulkSendJob List to return. Defaults to `1`.
        :type page: int
        :param page_size: Number of objects to be returned per page. Must be between `1` and `100`. Default is 20.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._bulk_send_job_list_serialize(
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "BulkSendJobListResponse",
            "4XX": "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _bulk_send_job_list_serialize(
        self,
        page,
        page_size,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if page is not None:

            _query_params.append(("page", page))

        if page_size is not None:

            _query_params.append(("page_size", page_size))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["api_key", "oauth2"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/bulk_send_job/list",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SubFormFieldsPerDocumentTypeEnum(str, Enum):
    """
    SubFormFieldsPerDocumentTypeEnum
    """

    """
    allowed enum values
    """
    CHECKBOX = "checkbox"
    CHECKBOX_MINUS_MERGE = "checkbox-merge"
    DATE_SIGNED = "date_signed"
    DROPDOWN = "dropdown"
    HYPERLINK = "hyperlink"
    INITIALS = "initials"
    SIGNATURE = "signature"
    RADIO = "radio"
    TEXT = "text"
    TEXT_MINUS_MERGE = "text-merge"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SubFormFieldsPerDocumentTypeEnum from a JSON string"""
        return cls(json.loads(json_str))



# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from dropbox_sign.models.list_info_response import ListInfoResponse
from dropbox_sign.models.template_response import TemplateResponse
from dropbox_sign.models.warning_response import WarningResponse
from typing import Optional, Set, Tuple
from typing_extensions import Self
import io
from pydantic import StrictBool
from typing import Union


class TemplateListResponse(BaseModel):
    """
    TemplateListResponse
    """  # noqa: E501

    templates: List[TemplateResponse] = Field(
        description="List of templates that the API caller has access to."
    )
    list_info: ListInfoResponse
    warnings: Optional[List[WarningResponse]] = Field(
        default=None, description="A list of warnings."
    )
    __properties: ClassVar[List[str]] = ["templates", "list_info", "warnings"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        arbitrary_types_allowed=True,
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    def to_json_form_params(
        self, excluded_fields: Set[str] = None
    ) -> List[Tuple[str, str]]:
        data: List[Tuple[str, str]] = []

        for key, value in self.to_dict(excluded_fields).items():
            if isinstance(value, (int, str, bool)):
                data.append((key, value))
            else:
                data.append((key, json.dumps(value, ensure_ascii=False)))

        return data

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TemplateListResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self, excluded_fields: Set[str] = None) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in templates (list)
        _items = []
        if self.templates:
            for _item_templates in self.templates:
                if _item_templates:
                    _items.append(_item_templates.to_dict())
            _dict["templates"] = _items
        # override the default output from pydantic by calling `to_dict()` of list_info
        if self.list_info:
            _dict["list_info"] = self.list_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in warnings (list)
        _items = []
        if self.warnings:
            for _item_warnings in self.warnings:
                if _item_warnings:
                    _items.append(_item_warnings.to_dict())
            _dict["warnings"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TemplateListResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "templates": (
                    [TemplateResponse.from_dict(_item) for _item in obj["templates"]]
                    if obj.get("templates") is not None
                    else None
                ),
                "list_info": (
                    ListInfoResponse.from_dict(obj["list_info"])
                    if obj.get("list_info") is not None
                    else None
                ),
                "warnings": (
                    [WarningResponse.from_dict(_item) for _item in obj["warnings"]]
                    if obj.get("warnings") is not None
                    else None
                ),
            }
        )
        return _obj

    @classmethod
    def init(cls, data: Any) -> Self:
        """
        Attempt to instantiate and hydrate a new instance of this class
        """
        if isinstance(data, str):
            data = json.loads(data)

        return cls.from_dict(data)

    @classmethod
    def openapi_types(cls) -> Dict[str, str]:
        return {
            "templates": "(List[TemplateResponse],)",
            "list_info": "(ListInfoResponse,)",
            "warnings": "(List[WarningResponse],)",
        }

    @classmethod
    def openapi_type_is_array(cls, property_name: str) -> bool:
        return property_name in [
            "templates",
            "warnings",
        ]



# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from dropbox_sign.models.api_app_response_o_auth import ApiAppResponseOAuth
from dropbox_sign.models.api_app_response_options import ApiAppResponseOptions
from dropbox_sign.models.api_app_response_owner_account import (
    ApiAppResponseOwnerAccount,
)
from dropbox_sign.models.api_app_response_white_labeling_options import (
    ApiAppResponseWhiteLabelingOptions,
)
from typing import Optional, Set, Tuple
from typing_extensions import Self
import io
from pydantic import StrictBool
from typing import Union


class ApiAppResponse(BaseModel):
    """
    Contains information about an API App.
    """  # noqa: E501

    callback_url: Optional[StrictStr] = Field(
        default=None, description="The app's callback URL (for events)"
    )
    client_id: Optional[StrictStr] = Field(
        default=None, description="The app's client id"
    )
    created_at: Optional[StrictInt] = Field(
        default=None, description="The time that the app was created"
    )
    domains: Optional[List[StrictStr]] = Field(
        default=None, description="The domain name(s) associated with the app"
    )
    name: Optional[StrictStr] = Field(default=None, description="The name of the app")
    is_approved: Optional[StrictBool] = Field(
        default=None, description="Boolean to indicate if the app has been approved"
    )
    oauth: Optional[ApiAppResponseOAuth] = None
    options: Optional[ApiAppResponseOptions] = None
    owner_account: Optional[ApiAppResponseOwnerAccount] = None
    white_labeling_options: Optional[ApiAppResponseWhiteLabelingOptions] = None
    __properties: ClassVar[List[str]] = [
        "callback_url",
        "client_id",
        "created_at",
        "domains",
        "name",
        "is_approved",
        "oauth",
        "options",
        "owner_account",
        "white_labeling_options",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        arbitrary_types_allowed=True,
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    def to_json_form_params(
        self, excluded_fields: Set[str] = None
    ) -> List[Tuple[str, str]]:
        data: List[Tuple[str, str]] = []

        for key, value in self.to_dict(excluded_fields).items():
            if isinstance(value, (int, str, bool)):
                data.append((key, value))
            else:
                data.append((key, json.dumps(value, ensure_ascii=False)))

        return data

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiAppResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self, excluded_fields: Set[str] = None) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of oauth
        if self.oauth:
            _dict["oauth"] = self.oauth.to_dict()
        # override the default output from pydantic by calling `to_dict()` of options
        if self.options:
            _dict["options"] = self.options.to_dict()
        # override the default output from pydantic by calling `to_dict()` of owner_account
        if self.owner_account:
            _dict["owner_account"] = self.owner_account.to_dict()
        # override the default output from pydantic by calling `to_dict()` of white_labeling_options
        if self.white_labeling_options:
            _dict["white_labeling_options"] = self.white_labeling_options.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiAppResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "callback_url": obj.get("callback_url"),
                "client_id": obj.get("client_id"),
                "created_at": obj.get("created_at"),
                "domains": obj.get("domains"),
                "name": obj.get("name"),
                "is_approved": obj.get("is_approved"),
                "oauth": (
                    ApiAppResponseOAuth.from_dict(obj["oauth"])
                    if obj.get("oauth") is not None
                    else None
                ),
                "options": (
                    ApiAppResponseOptions.from_dict(obj["options"])
                    if obj.get("options") is not None
                    else None
                ),
                "owner_account": (
                    ApiAppResponseOwnerAccount.from_dict(obj["owner_account"])
                    if obj.get("owner_account") is not None
                    else None
                ),
                "white_labeling_options": (
                    ApiAppResponseWhiteLabelingOptions.from_dict(
                        obj["white_labeling_options"]
                    )
                    if obj.get("white_labeling_options") is not None
                    else None
                ),
            }
        )
        return _obj

    @classmethod
    def init(cls, data: Any) -> Self:
        """
        Attempt to instantiate and hydrate a new instance of this class
        """
        if isinstance(data, str):
            data = json.loads(data)

        return cls.from_dict(data)

    @classmethod
    def openapi_types(cls) -> Dict[str, str]:
        return {
            "callback_url": "(str,)",
            "client_id": "(str,)",
            "created_at": "(int,)",
            "domains": "(List[str],)",
            "name": "(str,)",
            "is_approved": "(bool,)",
            "oauth": "(ApiAppResponseOAuth,)",
            "options": "(ApiAppResponseOptions,)",
            "owner_account": "(ApiAppResponseOwnerAccount,)",
            "white_labeling_options": "(ApiAppResponseWhiteLabelingOptions,)",
        }

    @classmethod
    def openapi_type_is_array(cls, property_name: str) -> bool:
        return property_name in [
            "domains",
        ]



# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBytes, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from dropbox_sign.models.sub_o_auth import SubOAuth
from dropbox_sign.models.sub_options import SubOptions
from dropbox_sign.models.sub_white_labeling_options import SubWhiteLabelingOptions
from typing import Optional, Set, Tuple
from typing_extensions import Self
import io
from pydantic import StrictBool
from typing import Union


class ApiAppCreateRequest(BaseModel):
    """
    ApiAppCreateRequest
    """  # noqa: E501

    domains: Annotated[List[StrictStr], Field(min_length=1, max_length=2)] = Field(
        description="The domain names the ApiApp will be associated with."
    )
    name: StrictStr = Field(description="The name you want to assign to the ApiApp.")
    callback_url: Optional[StrictStr] = Field(
        default=None,
        description="The URL at which the ApiApp should receive event callbacks.",
    )
    custom_logo_file: Optional[Union[StrictBytes, StrictStr, io.IOBase]] = Field(
        default=None,
        description="An image file to use as a custom logo in embedded contexts. (Only applies to some API plans)",
    )
    oauth: Optional[SubOAuth] = None
    options: Optional[SubOptions] = None
    white_labeling_options: Optional[SubWhiteLabelingOptions] = None
    __properties: ClassVar[List[str]] = [
        "domains",
        "name",
        "callback_url",
        "custom_logo_file",
        "oauth",
        "options",
        "white_labeling_options",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        arbitrary_types_allowed=True,
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    def to_json_form_params(
        self, excluded_fields: Set[str] = None
    ) -> List[Tuple[str, str]]:
        data: List[Tuple[str, str]] = []

        for key, value in self.to_dict(excluded_fields).items():
            if isinstance(value, (int, str, bool)):
                data.append((key, value))
            else:
                data.append((key, json.dumps(value, ensure_ascii=False)))

        return data

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiAppCreateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self, excluded_fields: Set[str] = None) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of oauth
        if self.oauth:
            _dict["oauth"] = self.oauth.to_dict()
        # override the default output from pydantic by calling `to_dict()` of options
        if self.options:
            _dict["options"] = self.options.to_dict()
        # override the default output from pydantic by calling `to_dict()` of white_labeling_options
        if self.white_labeling_options:
            _dict["white_labeling_options"] = self.white_labeling_options.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiAppCreateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "domains": obj.get("domains"),
                "name": obj.get("name"),
                "callback_url": obj.get("callback_url"),
                "custom_logo_file": obj.get("custom_logo_file"),
                "oauth": (
                    SubOAuth.from_dict(obj["oauth"])
                    if obj.get("oauth") is not None
                    else None
                ),
                "options": (
                    SubOptions.from_dict(obj["options"])
                    if obj.get("options") is not None
                    else None
                ),
                "white_labeling_options": (
                    SubWhiteLabelingOptions.from_dict(obj["white_labeling_options"])
                    if obj.get("white_labeling_options") is not None
                    else None
                ),
            }
        )
        return _obj

    @classmethod
    def init(cls, data: Any) -> Self:
        """
        Attempt to instantiate and hydrate a new instance of this class
        """
        if isinstance(data, str):
            data = json.loads(data)

        return cls.from_dict(data)

    @classmethod
    def openapi_types(cls) -> Dict[str, str]:
        return {
            "domains": "(List[str],)",
            "name": "(str,)",
            "callback_url": "(str,)",
            "custom_logo_file": "(io.IOBase,)",
            "oauth": "(SubOAuth,)",
            "options": "(SubOptions,)",
            "white_labeling_options": "(SubWhiteLabelingOptions,)",
        }

    @classmethod
    def openapi_type_is_array(cls, property_name: str) -> bool:
        return property_name in [
            "domains",
        ]



import os
import json
import urllib3
from urllib.parse import urlparse
from urllib.parse import parse_qs


def get_base_path():
    return os.path.dirname(os.path.abspath(__file__)) + f"/../test_fixtures"


def get_fixture_data(filename):
    path = get_base_path() + f"/{filename}.json"

    file = open(path, "r")
    fixture_data = json.load(file)
    file.close()

    return fixture_data


class MockPoolManager(object):
    def __init__(self, tc):
        self._tc = tc
        self._expected_request = {}
        self._expected_response = {}
        self._request_fields = []
        self._query_params = {}

    def expect_request(self, content_type, data=None, response=None, status=200):
        self._expected_request = {
            "content_type": content_type,
            "data": data,
        }
        self._expected_response = {
            "data": response,
            "status": status,
        }

    def request(self, *args, **kwargs):
        if self._expected_request["content_type"] == "multipart/form-data":
            self._tc.assertTrue("encode_multipart" in kwargs.keys())
            self._tc.assertTrue(kwargs["encode_multipart"])
        else:
            self._tc.assertFalse("encode_multipart" in kwargs.keys())

        if "fields" in kwargs:
            self._request_fields = kwargs["fields"]

        self._query_params = parse_qs(urlparse(args[1]).query)

        return urllib3.HTTPResponse(
            status=self._expected_response["status"],
            preload_content=True,
            body=json.dumps(self._expected_response["data"]).encode(),
        )

    def get_fields(self):
        return self._request_fields

    def get_query_params(self):
        return self._query_params



# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictBytes, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from dropbox_sign.models.sub_bulk_signer_list import SubBulkSignerList
from dropbox_sign.models.sub_cc import SubCC
from dropbox_sign.models.sub_custom_field import SubCustomField
from typing import Optional, Set, Tuple
from typing_extensions import Self
import io
from pydantic import StrictBool
from typing import Union


class SignatureRequestBulkCreateEmbeddedWithTemplateRequest(BaseModel):
    """
    SignatureRequestBulkCreateEmbeddedWithTemplateRequest
    """  # noqa: E501

    template_ids: List[StrictStr] = Field(
        description="Use `template_ids` to create a SignatureRequest from one or more templates, in the order in which the template will be used."
    )
    client_id: StrictStr = Field(
        description="Client id of the app you're using to create this embedded signature request. Used for security purposes."
    )
    signer_file: Optional[Union[StrictBytes, StrictStr, io.IOBase]] = Field(
        default=None,
        description="`signer_file` is a CSV file defining values and options for signer fields. Required unless a `signer_list` is used, you may not use both. The CSV can have the following columns:  - `name`: the name of the signer filling the role of RoleName - `email_address`: email address of the signer filling the role of RoleName - `pin`: the 4- to 12-character access code that will secure this signer's signature page (optional) - `sms_phone_number`: An E.164 formatted phone number that will receive a code via SMS to access this signer's signature page. (optional)      By using the feature, you agree you are responsible for obtaining a signer's consent to receive text messages from Dropbox Sign related to this signature request and confirm you have obtained such consent from all signers prior to enabling SMS delivery for this signature request. [Learn more](https://faq.hellosign.com/hc/en-us/articles/15815316468877-Dropbox-Sign-SMS-tools-add-on).      **NOTE:** Not available in test mode and requires a Standard plan or higher. - `*_field`: any column with a _field\" suffix will be treated as a custom field (optional)      You may only specify field values here, any other options should be set in the custom_fields request parameter.  Example CSV:  ``` name, email_address, pin, company_field George, george@example.com, d79a3td, ABC Corp Mary, mary@example.com, gd9as5b, 123 LLC ```",
    )
    signer_list: Optional[List[SubBulkSignerList]] = Field(
        default=None,
        description="`signer_list` is an array defining values and options for signer fields. Required unless a `signer_file` is used, you may not use both.",
    )
    allow_decline: Optional[StrictBool] = Field(
        default=False,
        description="Allows signers to decline to sign a document if `true`. Defaults to `false`.",
    )
    ccs: Optional[List[SubCC]] = Field(
        default=None,
        description="Add CC email recipients. Required when a CC role exists for the Template.",
    )
    custom_fields: Optional[List[SubCustomField]] = Field(
        default=None,
        description='When used together with merge fields, `custom_fields` allows users to add pre-filled data to their signature requests.  Pre-filled data can be used with "send-once" signature requests by adding merge fields with `form_fields_per_document` or [Text Tags](https://app.hellosign.com/api/textTagsWalkthrough#TextTagIntro) while passing values back with `custom_fields` together in one API call.  For using pre-filled on repeatable signature requests, merge fields are added to templates in the Dropbox Sign UI or by calling [/template/create_embedded_draft](/api/reference/operation/templateCreateEmbeddedDraft) and then passing `custom_fields` on subsequent signature requests referencing that template.',
    )
    message: Optional[Annotated[str, Field(strict=True, max_length=5000)]] = Field(
        default=None,
        description="The custom message in the email that will be sent to the signers.",
    )
    metadata: Optional[Dict[str, Any]] = Field(
        default=None,
        description="Key-value data that should be attached to the signature request. This metadata is included in all API responses and events involving the signature request. For example, use the metadata field to store a signer's order number for look up when receiving events for the signature request.  Each request can include up to 10 metadata keys (or 50 nested metadata keys), with key names up to 40 characters long and values up to 1000 characters long.",
    )
    signing_redirect_url: Optional[StrictStr] = Field(
        default=None,
        description="The URL you want signers redirected to after they successfully sign.",
    )
    subject: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(
        default=None,
        description="The subject in the email that will be sent to the signers.",
    )
    test_mode: Optional[StrictBool] = Field(
        default=False,
        description="Whether this is a test, the signature request will not be legally binding if set to `true`. Defaults to `false`.",
    )
    title: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(
        default=None,
        description="The title you want to assign to the SignatureRequest.",
    )
    __properties: ClassVar[List[str]] = [
        "template_ids",
        "client_id",
        "signer_file",
        "signer_list",
        "allow_decline",
        "ccs",
        "custom_fields",
        "message",
        "metadata",
        "signing_redirect_url",
        "subject",
        "test_mode",
        "title",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        arbitrary_types_allowed=True,
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    def to_json_form_params(
        self, excluded_fields: Set[str] = None
    ) -> List[Tuple[str, str]]:
        data: List[Tuple[str, str]] = []

        for key, value in self.to_dict(excluded_fields).items():
            if isinstance(value, (int, str, bool)):
                data.append((key, value))
            else:
                data.append((key, json.dumps(value, ensure_ascii=False)))

        return data

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SignatureRequestBulkCreateEmbeddedWithTemplateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self, excluded_fields: Set[str] = None) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in signer_list (list)
        _items = []
        if self.signer_list:
            for _item_signer_list in self.signer_list:
                if _item_signer_list:
                    _items.append(_item_signer_list.to_dict())
            _dict["signer_list"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in ccs (list)
        _items = []
        if self.ccs:
            for _item_ccs in self.ccs:
                if _item_ccs:
                    _items.append(_item_ccs.to_dict())
            _dict["ccs"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in custom_fields (list)
        _items = []
        if self.custom_fields:
            for _item_custom_fields in self.custom_fields:
                if _item_custom_fields:
                    _items.append(_item_custom_fields.to_dict())
            _dict["custom_fields"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SignatureRequestBulkCreateEmbeddedWithTemplateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "template_ids": obj.get("template_ids"),
                "client_id": obj.get("client_id"),
                "signer_file": obj.get("signer_file"),
                "signer_list": (
                    [SubBulkSignerList.from_dict(_item) for _item in obj["signer_list"]]
                    if obj.get("signer_list") is not None
                    else None
                ),
                "allow_decline": (
                    obj.get("allow_decline")
                    if obj.get("allow_decline") is not None
                    else False
                ),
                "ccs": (
                    [SubCC.from_dict(_item) for _item in obj["ccs"]]
                    if obj.get("ccs") is not None
                    else None
                ),
                "custom_fields": (
                    [SubCustomField.from_dict(_item) for _item in obj["custom_fields"]]
                    if obj.get("custom_fields") is not None
                    else None
                ),
                "message": obj.get("message"),
                "metadata": obj.get("metadata"),
                "signing_redirect_url": obj.get("signing_redirect_url"),
                "subject": obj.get("subject"),
                "test_mode": (
                    obj.get("test_mode") if obj.get("test_mode") is not None else False
                ),
                "title": obj.get("title"),
            }
        )
        return _obj

    @classmethod
    def init(cls, data: Any) -> Self:
        """
        Attempt to instantiate and hydrate a new instance of this class
        """
        if isinstance(data, str):
            data = json.loads(data)

        return cls.from_dict(data)

    @classmethod
    def openapi_types(cls) -> Dict[str, str]:
        return {
            "template_ids": "(List[str],)",
            "client_id": "(str,)",
            "signer_file": "(io.IOBase,)",
            "signer_list": "(List[SubBulkSignerList],)",
            "allow_decline": "(bool,)",
            "ccs": "(List[SubCC],)",
            "custom_fields": "(List[SubCustomField],)",
            "message": "(str,)",
            "metadata": "(Dict[str, object],)",
            "signing_redirect_url": "(str,)",
            "subject": "(str,)",
            "test_mode": "(bool,)",
            "title": "(str,)",
        }

    @classmethod
    def openapi_type_is_array(cls, property_name: str) -> bool:
        return property_name in [
            "template_ids",
            "signer_list",
            "ccs",
            "custom_fields",
        ]



import unittest

from dropbox_sign import ApiClient, Configuration, apis, models as m
from test_utils import get_fixture_data, MockPoolManager, get_base_path


class TestSignatureRequestApi(unittest.TestCase):
    def setUp(self):
        self.configuration = Configuration()
        self.api_client = ApiClient(self.configuration)
        self.mock_pool = MockPoolManager(self)
        self.api_client.rest_client.pool_manager = self.mock_pool

        self.api = apis.SignatureRequestApi(self.api_client)

    def test_init_allows_binary_file(self):
        data = {
            "test_mode": True,
            "title": "NDA with Acme Co.",
            "subject": "The NDA we talked about",
            "message": "Please sign this NDA and then we can discuss more.",
            "signers": [
                {"email_address": "jill@example.com", "name": "Jill", "order": 1}
            ],
            "form_fields_per_document": [
                {
                    "type": "signature",
                    "document_index": 0,
                    "api_id": "4688957689",
                    "name": "signature1",
                    "x": 5,
                    "y": 7,
                    "width": 60,
                    "height": 30,
                    "required": True,
                    "signer": "0",
                    "page": 1,
                }
            ],
            "files": [open(get_base_path() + "/../test_fixtures/pdf-sample.pdf", "rb")],
        }

        obj = m.SignatureRequestSendRequest.init(data)

        self.assertEqual(data["test_mode"], obj.test_mode)
        self.assertEqual(data["title"], obj.title)
        self.assertEqual(data["subject"], obj.subject)
        self.assertEqual(data["message"], obj.message)

        self.assertEqual(
            data["signers"][0]["email_address"], obj.signers[0].email_address
        )
        self.assertEqual(data["signers"][0]["name"], obj.signers[0].name)
        self.assertEqual(data["signers"][0]["order"], obj.signers[0].order)

        self.assertEqual(
            data["form_fields_per_document"][0]["type"],
            obj.form_fields_per_document[0].type,
        )
        self.assertEqual(
            data["form_fields_per_document"][0]["document_index"],
            obj.form_fields_per_document[0].document_index,
        )
        self.assertEqual(
            data["form_fields_per_document"][0]["api_id"],
            obj.form_fields_per_document[0].api_id,
        )
        self.assertEqual(
            data["form_fields_per_document"][0]["name"],
            obj.form_fields_per_document[0].name,
        )
        self.assertEqual(
            data["form_fields_per_document"][0]["x"], obj.form_fields_per_document[0].x
        )
        self.assertEqual(
            data["form_fields_per_document"][0]["y"], obj.form_fields_per_document[0].y
        )
        self.assertEqual(
            data["form_fields_per_document"][0]["width"],
            obj.form_fields_per_document[0].width,
        )
        self.assertEqual(
            data["form_fields_per_document"][0]["height"],
            obj.form_fields_per_document[0].height,
        )
        self.assertEqual(
            data["form_fields_per_document"][0]["required"],
            obj.form_fields_per_document[0].required,
        )
        self.assertEqual(
            data["form_fields_per_document"][0]["signer"],
            obj.form_fields_per_document[0].signer,
        )
        self.assertEqual(
            data["form_fields_per_document"][0]["page"],
            obj.form_fields_per_document[0].page,
        )

        self.assertEqual(data["files"][0], obj.files[0])

        obj.files[0].close()

    def test_init_allows_jsony_chars_in_strings(self):
        title = "테스트 - testing japanese characters in subject"
        subject = "[テスト]"
        message = '{"テスト - testing message"}'

        request_data = {
            "test_mode": True,
            "title": title,
            "subject": subject,
            "message": message,
            "signers": [
                {"email_address": "jill@example.com", "name": "Jill", "order": 1}
            ],
            "files": [open(get_base_path() + "/../test_fixtures/pdf-sample.pdf", "rb")],
        }

        response_class = "SignatureRequestGetResponse"
        response_data = get_fixture_data(response_class)["default"]

        obj = m.SignatureRequestSendRequest.init(request_data)

        self.mock_pool.expect_request(
            content_type="multipart/form-data",
            data=request_data,
            response=response_data,
        )

        self.api.signature_request_send(obj)

        fields = self.mock_pool.get_fields()

        title_result = fields[9]
        subject_result = fields[7]
        message_result = fields[6]

        self.assertEqual(title_result[1], title)
        self.assertEqual(subject_result[1], subject)
        self.assertEqual(message_result[1], message)

        obj.files[0].close()

    def test_signature_request_bulk_create_embedded_with_template(self):
        request_class = "SignatureRequestBulkCreateEmbeddedWithTemplateRequest"
        request_data = get_fixture_data(request_class)["default"]

        response_class = "BulkSendJobSendResponse"
        response_data = get_fixture_data(response_class)["default"]

        self.mock_pool.expect_request(
            content_type="multipart/form-data",
            data=request_data,
            response=response_data,
        )
        expected = m.BulkSendJobSendResponse.init(response_data)
        obj = m.SignatureRequestBulkCreateEmbeddedWithTemplateRequest.init(request_data)
        obj.signer_file = open(f"{get_base_path()}/bulk-send-sample.csv", "rb")

        result = self.api.signature_request_bulk_create_embedded_with_template(obj)

        self.assertEqual(result.__class__.__name__, response_class)
        self.assertEqual(result, expected)

        obj.signer_file.close()

    def test_signature_request_bulk_send_with_template(self):
        request_class = "SignatureRequestBulkSendWithTemplateRequest"
        request_data = get_fixture_data(request_class)["default"]

        response_class = "BulkSendJobSendResponse"
        response_data = get_fixture_data(response_class)["default"]

        self.mock_pool.expect_request(
            content_type="multipart/form-data",
            data=request_data,
            response=response_data,
        )
        expected = m.BulkSendJobSendResponse.init(response_data)
        obj = m.SignatureRequestBulkSendWithTemplateRequest.init(request_data)
        obj.signer_file = open(f"{get_base_path()}/bulk-send-sample.csv", "rb")

        result = self.api.signature_request_bulk_send_with_template(obj)

        self.assertEqual(result.__class__.__name__, response_class)
        self.assertEqual(result, expected)

        obj.signer_file.close()

    def test_signature_request_create_embedded(self):
        request_class = "SignatureRequestCreateEmbeddedRequest"
        request_data = get_fixture_data(request_class)["default"]

        response_class = "SignatureRequestGetResponse"
        response_data = get_fixture_data(response_class)["default"]

        self.mock_pool.expect_request(
            content_type="multipart/form-data",
            data=request_data,
            response=response_data,
        )
        expected = m.SignatureRequestGetResponse.init(response_data)
        obj = m.SignatureRequestCreateEmbeddedRequest.init(request_data)
        obj.files = [open(f"{get_base_path()}/pdf-sample.pdf", "rb")]

        result = self.api.signature_request_create_embedded(obj)

        self.assertEqual(result.__class__.__name__, response_class)
        self.assertEqual(result, expected)

        obj.files[0].close()

    def test_signature_request_create_embedded_with_template(self):
        request_class = "SignatureRequestCreateEmbeddedWithTemplateRequest"
        request_data = get_fixture_data(request_class)["default"]

        response_class = "SignatureRequestGetResponse"
        response_data = get_fixture_data(response_class)["default"]

        self.mock_pool.expect_request(
            content_type="multipart/form-data",
            data=request_data,
            response=response_data,
        )
        expected = m.SignatureRequestGetResponse.init(response_data)
        obj = m.SignatureRequestCreateEmbeddedWithTemplateRequest.init(request_data)
        obj.files = [open(f"{get_base_path()}/pdf-sample.pdf", "rb")]

        result = self.api.signature_request_create_embedded_with_template(obj)

        self.assertEqual(result.__class__.__name__, response_class)
        self.assertEqual(result, expected)

        obj.files[0].close()

    def test_signature_request_files(self):
        self.skipTest("skipping test_signature_request_files")

    def test_signature_request_get(self):
        signature_request_id = "fa5c8a0b0f492d768749333ad6fcc214c111e967"

        response_class = "SignatureRequestGetResponse"
        response_data = get_fixture_data(response_class)["default"]

        self.mock_pool.expect_request(
            content_type="application/json", response=response_data
        )
        expected = m.SignatureRequestGetResponse.init(response_data)

        result = self.api.signature_request_get(signature_request_id)

        self.assertEqual(result.__class__.__name__, response_class)
        self.assertEqual(result, expected)

    def test_signature_request_list(self):
        account_id = "all"

        response_class = "SignatureRequestListResponse"
        response_data = get_fixture_data(response_class)["default"]

        self.mock_pool.expect_request(
            content_type="application/json", response=response_data
        )
        expected = m.SignatureRequestListResponse.init(response_data)

        result = self.api.signature_request_list(account_id=account_id)

        self.assertEqual(result.__class__.__name__, response_class)
        self.assertEqual(result, expected)

    def test_signature_request_list_null_query_value_removed(self):
        account_id = None

        self.mock_pool.expect_request(
            content_type="application/json",
            response=None,
        )

        self.api.signature_request_list(account_id=account_id)

        request_fields = self.mock_pool.get_query_params()
        self.assertTrue(not request_fields)

        account_id = None
        query = None

        self.mock_pool.expect_request(
            content_type="application/json",
            response=None,
        )

        self.api.signature_request_list(account_id=account_id, query=query)

        request_fields = self.mock_pool.get_query_params()
        self.assertTrue(not request_fields)

        account_id = "ABC123"
        query = None

        self.mock_pool.expect_request(
            content_type="application/json",
            response=None,
        )

        self.api.signature_request_list(account_id=account_id, query=query)

        request_fields = self.mock_pool.get_query_params()
        expected_fields = {
            "account_id": [account_id],
        }
        self.assertEqual(expected_fields, request_fields)

        account_id = "ABC123"
        query = "My amazing query"

        self.mock_pool.expect_request(
            content_type="application/json",
            response=None,
        )

        self.api.signature_request_list(account_id=account_id, query=query)

        request_fields = self.mock_pool.get_query_params()
        expected_fields = {
            "account_id": [account_id],
            "query": [query],
        }
        self.assertEqual(expected_fields, request_fields)

    def test_signature_request_release_hold(self):
        signature_request_id = "fa5c8a0b0f492d768749333ad6fcc214c111e967"

        response_class = "SignatureRequestGetResponse"
        response_data = get_fixture_data(response_class)["default"]

        self.mock_pool.expect_request(
            content_type="application/json", response=response_data
        )
        expected = m.SignatureRequestGetResponse.init(response_data)

        result = self.api.signature_request_release_hold(signature_request_id)

        self.assertEqual(result.__class__.__name__, response_class)
        self.assertEqual(result, expected)

    def test_signature_request_remind(self):
        signature_request_id = "fa5c8a0b0f492d768749333ad6fcc214c111e967"

        request_class = "SignatureRequestRemindRequest"
        request_data = get_fixture_data(request_class)["default"]

        response_class = "SignatureRequestGetResponse"
        response_data = get_fixture_data(response_class)["default"]

        self.mock_pool.expect_request(
            content_type="application/json", data=request_data, response=response_data
        )
        expected = m.SignatureRequestGetResponse.init(response_data)
        obj = m.SignatureRequestRemindRequest.init(request_data)

        result = self.api.signature_request_remind(signature_request_id, obj)

        self.assertEqual(result.__class__.__name__, response_class)
        self.assertEqual(result, expected)

    def test_signature_request_remove(self):
        self.skipTest("skipping test_signature_request_remove")

    def test_signature_request_send_request(self):
        request_class = "SignatureRequestSendRequest"
        request_data = get_fixture_data(request_class)["default"]

        response_class = "SignatureRequestGetResponse"
        response_data = get_fixture_data(response_class)["default"]

        self.mock_pool.expect_request(
            content_type="multipart/form-data",
            data=request_data,
            response=response_data,
        )
        expected = m.SignatureRequestGetResponse.init(response_data)
        obj = m.SignatureRequestSendRequest.init(request_data)
        obj.files = [open(f"{get_base_path()}/pdf-sample.pdf", "rb")]

        result = self.api.signature_request_send(obj)

        self.assertEqual(result.__class__.__name__, response_class)
        self.assertEqual(result, expected)

        obj.files[0].close()

    def test_no_file_forces_application_json(self):
        request_class = "SignatureRequestSendRequest"
        request_data = get_fixture_data(request_class)["default"]

        response_class = "SignatureRequestGetResponse"
        response_data = get_fixture_data(response_class)["default"]

        self.mock_pool.expect_request(
            content_type="application/json", data=request_data, response=response_data
        )
        expected = m.SignatureRequestGetResponse.init(response_data)
        obj = m.SignatureRequestSendRequest.init(request_data)

        result = self.api.signature_request_send(obj)

        self.assertEqual(result.__class__.__name__, response_class)
        self.assertEqual(result, expected)

    def test_signature_request_send_with_template(self):
        request_class = "SignatureRequestSendWithTemplateRequest"
        request_data = get_fixture_data(request_class)["default"]

        response_class = "SignatureRequestGetResponse"
        response_data = get_fixture_data(response_class)["default"]

        self.mock_pool.expect_request(
            content_type="application/json", data=request_data, response=response_data
        )
        expected = m.SignatureRequestGetResponse.init(response_data)
        obj = m.SignatureRequestSendWithTemplateRequest.init(request_data)

        result = self.api.signature_request_send_with_template(obj)

        self.assertEqual(result.__class__.__name__, response_class)
        self.assertEqual(result, expected)

    def test_signature_request_update(self):
        signature_request_id = "fa5c8a0b0f492d768749333ad6fcc214c111e967"

        request_class = "SignatureRequestUpdateRequest"
        request_data = get_fixture_data(request_class)["default"]

        response_class = "SignatureRequestGetResponse"
        response_data = get_fixture_data(response_class)["default"]

        self.mock_pool.expect_request(
            content_type="application/json", data=request_data, response=response_data
        )
        expected = m.SignatureRequestGetResponse.init(response_data)
        obj = m.SignatureRequestUpdateRequest.init(request_data)

        result = self.api.signature_request_update(signature_request_id, obj)

        self.assertEqual(result.__class__.__name__, response_class)
        self.assertEqual(result, expected)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Dropbox Sign API

    Dropbox Sign v3 API

    The version of the OpenAPI document: 3.0.0
    Contact: apisupport@hellosign.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class FaxLineAreaCodeGetStateEnum(str, Enum):
    """
    FaxLineAreaCodeGetStateEnum
    """

    """
    allowed enum values
    """
    AK = "AK"
    AL = "AL"
    AR = "AR"
    AZ = "AZ"
    CA = "CA"
    CO = "CO"
    CT = "CT"
    DC = "DC"
    DE = "DE"
    FL = "FL"
    GA = "GA"
    HI = "HI"
    IA = "IA"
    ID = "ID"
    IL = "IL"
    IN = "IN"
    KS = "KS"
    KY = "KY"
    LA = "LA"
    MA = "MA"
    MD = "MD"
    ME = "ME"
    MI = "MI"
    MN = "MN"
    MO = "MO"
    MS = "MS"
    MT = "MT"
    NC = "NC"
    ND = "ND"
    NE = "NE"
    NH = "NH"
    NJ = "NJ"
    NM = "NM"
    NV = "NV"
    NY = "NY"
    OH = "OH"
    OK = "OK"
    OR = "OR"
    PA = "PA"
    RI = "RI"
    SC = "SC"
    SD = "SD"
    TN = "TN"
    TX = "TX"
    UT = "UT"
    VA = "VA"
    VT = "VT"
    WA = "WA"
    WI = "WI"
    WV = "WV"
    WY = "WY"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of FaxLineAreaCodeGetStateEnum from a JSON string"""
        return cls(json.loads(json_str))
